@@ -15,8 +15,8 @@
 // along with the snarkVM library. If not, see <https://www.gnu.org/licenses/>.
 
 use crate::{
-    impl_additive_ops_from_ref,
-    impl_multiplicative_ops_from_ref,
+    impl_add_sub_from_field_ref,
+    impl_mul_div_from_field_ref,
     FftField,
     Field,
     FieldError,
@@ -31,8 +31,9 @@ use crate::{
 };
 use snarkvm_utilities::{
     biginteger::{arithmetic as fa, BigInteger as _BigInteger, BigInteger768 as BigInteger},
-    bytes::{FromBytes, ToBytes},
     serialize::CanonicalDeserialize,
+    FromBytes,
+    ToBytes,
 };
 
 use std::{
@@ -668,7 +669,7 @@ impl<P: Fp768Parameters> PrimeField for Fp768<P> {
     }
 
     #[inline]
-    fn into_repr(&self) -> BigInteger {
+    fn to_repr(&self) -> BigInteger {
         let mut r = *self;
         r.mont_reduce(
             (self.0).0[0],
@@ -700,13 +701,13 @@ impl<P: Fp768Parameters> PrimeField for Fp768<P> {
     }
 
     #[inline]
-    fn from_repr_raw(r: BigInteger) -> Self {
+    fn from_repr_unchecked(r: BigInteger) -> Self {
         let r = Fp768(r, PhantomData);
         if r.is_valid() { r } else { Self::zero() }
     }
 
     #[inline]
-    fn into_repr_raw(&self) -> BigInteger {
+    fn to_repr_unchecked(&self) -> BigInteger {
         let r = *self;
         r.0
     }
@@ -785,7 +786,7 @@ impl<P: Fp768Parameters> SquareRootField for Fp768<P> {
 impl<P: Fp768Parameters> Ord for Fp768<P> {
     #[inline(always)]
     fn cmp(&self, other: &Self) -> Ordering {
-        self.into_repr().cmp(&other.into_repr())
+        self.to_repr().cmp(&other.to_repr())
     }
 }
 
@@ -796,28 +797,28 @@ impl<P: Fp768Parameters> PartialOrd for Fp768<P> {
     }
 }
 
-impl_prime_field_from_int!(Fp768, u128, Fp768Parameters);
-impl_prime_field_from_int!(Fp768, u64, Fp768Parameters);
-impl_prime_field_from_int!(Fp768, u32, Fp768Parameters);
-impl_prime_field_from_int!(Fp768, u16, Fp768Parameters);
-impl_prime_field_from_int!(Fp768, u8, Fp768Parameters);
+impl_primefield_from_int!(Fp768, u128, Fp768Parameters);
+impl_primefield_from_int!(Fp768, u64, Fp768Parameters);
+impl_primefield_from_int!(Fp768, u32, Fp768Parameters);
+impl_primefield_from_int!(Fp768, u16, Fp768Parameters);
+impl_primefield_from_int!(Fp768, u8, Fp768Parameters);
 
-impl_prime_field_standard_sample!(Fp768, Fp768Parameters);
+impl_primefield_standard_sample!(Fp768, Fp768Parameters);
 
-impl_additive_ops_from_ref!(Fp768, Fp768Parameters);
-impl_multiplicative_ops_from_ref!(Fp768, Fp768Parameters);
+impl_add_sub_from_field_ref!(Fp768, Fp768Parameters);
+impl_mul_div_from_field_ref!(Fp768, Fp768Parameters);
 
 impl<P: Fp768Parameters> ToBytes for Fp768<P> {
     #[inline]
-    fn write<W: Write>(&self, writer: W) -> IoResult<()> {
-        self.into_repr().write(writer)
+    fn write_le<W: Write>(&self, writer: W) -> IoResult<()> {
+        self.to_repr().write_le(writer)
     }
 }
 
 impl<P: Fp768Parameters> FromBytes for Fp768<P> {
     #[inline]
-    fn read<R: Read>(reader: R) -> IoResult<Self> {
-        BigInteger::read(reader).and_then(|b| match Self::from_repr(b) {
+    fn read_le<R: Read>(reader: R) -> IoResult<Self> {
+        BigInteger::read_le(reader).and_then(|b| match Self::from_repr(b) {
             Some(f) => Ok(f),
             None => Err(FieldError::InvalidFieldElement.into()),
         })
@@ -878,14 +879,14 @@ impl<P: Fp768Parameters> FromStr for Fp768<P> {
 impl<P: Fp768Parameters> Debug for Fp768<P> {
     #[inline]
     fn fmt(&self, f: &mut Formatter<'_>) -> FmtResult {
-        write!(f, "Fp768({})", self.into_repr())
+        write!(f, "Fp768({})", self.to_repr())
     }
 }
 
 impl<P: Fp768Parameters> Display for Fp768<P> {
     #[inline]
     fn fmt(&self, f: &mut Formatter<'_>) -> FmtResult {
-        write!(f, "{}", self.into_repr())
+        write!(f, "{}", self.to_repr())
     }
 }
 
@@ -1162,7 +1163,7 @@ impl<P: Fp768Parameters + PoseidonMDSParameters> PoseidonMDSField for Fp768<P> {
         for row in P::POSEIDON_MDS.iter() {
             mds.push(
                 row.iter()
-                    .map(|b| Self::from_repr_raw(*b))
+                    .map(|b| Self::from_repr_unchecked(*b))
                     .collect::<Vec<Self>>()
                     .to_vec(),
             );
